%%% Solving uniform Euler beam by using NSA + CSM approach 
%%% This script is running with Chebfun Ver 5.1 toolbox 
%%% Dowload toolbox from website:  http://www.chebfun.org/download/
%%% To use Chebfun, its path must be added each time you start MATLAB;
%%% ----------------
% Define parameters of the Boundary Conditions at both ends
clear all;
b1 = 1e-5; % K_RL
b2 = 1e10; % K_TL
b3 = 1e-5; % K_RR
b4 = 1e10; % K_TR

% Define GE with Chebop
L = chebop(0,1);
L.op = @(x,y)(diff(y,4));

%  Define Partial clamped BCs at Both ends
L.lbc = @(y) [diff(y,2)-b1*diff(y) ; diff(y,3)+b2*y];
L.rbc = @(y) [diff(y,2)+b3*diff(y) ; diff(y,3)-b4*y];

% Null-space approach         
N =69; % chebpoints
% Convert chebop to linop 
[yL, ignored, fail] = linop(L) ;
% cheb-matrix realization
[P, PA, Bc, A1, PS] = matrix(yL, N);

% Null-space transform
Nd = max(size(A1{1}));
nuA = null(Bc);
Aend = nuA'*A1{1}*nuA;

% eigensolver
[Vx, Dx] = eig(Aend);
[dd, Sind]=sort(diag(Dx));
% Back from null-space to physical domain
Vx1 = nuA*Vx(:,Sind); % %

% Convert the eigenvalue to dimensionless frequency
nM = N; 
dd(1:nM).^0.25;

% Axes scaling for the plot
xp = chebpts(Nd, [0 1]);
uu = chebfun([xp,Vx1(:,1:nM)], [0 1]);%xp,
xxp = uu(:,1);
CV = uu(:,2:end);

% Plot the first 6th mode shapes
plot(xxp,CV(:,1:6),'Linewidth',2); grid
xlabel('Normalized length of the beam')
ylabel('Normalized mode shape')